@@ -34,7 +34,8 @@ def Len(arg):
        
     if type(arg) in [int, float]:
         return 1
-    elif arg == None or arg == [] or (isinstance(arg, ndarray) and arg.size==1 and arg == array(None, dtype=object)):
+    elif arg is None or (isinstance(arg, (list, tuple)) and len(arg) == 0) \
+    or (isinstance(arg, ndarray) and arg.size==1 and arg == array(None, dtype=object)):
         return 0
     else:
         return len(arg)
@@ -129,7 +130,7 @@ def LinConst2WholeRepr(p):
     transforms  (A, x) <= b, (Aeq, x) = beq into Awhole, bwhole, dwhole constraints (see help(LP))
     this func is developed for those solvers that can handle linear (in)equality constraints only via Awhole
     """
-    if p.A == None and p.Aeq == None:
+    if p.A is None and p.Aeq is None:
         return
     
     # new 
@@ -167,7 +168,7 @@ def WholeRepr2LinConst(p):
     transforms  Awhole, bwhole, dwhole  into (A, x) <= b, (Aeq, x) = beq constraints (see help(LP))
     this func is developed for those solvers that can handle linear (in)equality constraints only via Awhole
     """
-    if p.dwhole == None:
+    if p.dwhole is None:
         return
     #TODO: is flatten required in newest numpy versions?
     ind_less = where(p.dwhole == -1)[0]
